@@ -345,6 +345,8 @@ Fst <- function(inputFile, sizes = FALSE, pairs = FALSE, outputFile = "", dataTy
 #' @name IBD
 #' @title Isolation by distance
 #' @description Estimates isolation by distance by regression of genetic distance to geographical distance. See \href{../doc/all-menu-options.html#sub-option-5-isolation-by-distance-between-individuals}{this section} of the Genepop executable documentation for more information on individual-based analyses and \href{../doc/all-menu-options.html#sub-option-6-isolation-by-distance-between-groups}{this one} for group-based analyses.
+#' 
+#' Note that there must be an `InputFile`. This means in particular that analyses based on alternative input, such as an `IsolationFile`, as described in the stand-alone documentation, cannot be performed through this function. The `Genepop` executable must be used instead.
 #' @param inputFile The path of the input file, in Genepop format
 #' @param outputFile character: The path of the output file
 #' @param settingsFile character: The path of the settings file
@@ -387,11 +389,11 @@ ibd <- function(inputFile, outputFile = "", settingsFile = "",
     .check_bootstrap_args(bootstrapMethod, bootstrapNsim)
     
     if (statistic %in% c("a", "e", "a-like")) {
-        mc[[1L]] <- quote(.GIsolationByDistanceBetweenIndividuals)
+        mc[[1L]] <- get(".GIsolationByDistanceBetweenIndividuals",asNamespace("genepop"), inherits=FALSE)
         if (statistic == "a-like") 
             mc$statistic <- "default"
     } else if (statistic %in% c("SingleGeneDiv", "F/(1-F)")) {
-        mc[[1L]] <- quote(.GIsolationByDistanceBetweenGroups)
+        mc[[1L]] <- get(".GIsolationByDistanceBetweenGroups",asNamespace("genepop"), inherits=FALSE)
         if (statistic == "F/(1-F)") 
             mc$statistic <- "default"
     } else stop("unknown 'statistic'")
