@@ -422,7 +422,7 @@ int CABCbootstrap::bootstrapOverLociABC(// Function returning the statistic of i
   for (size_t loc=0;loc<nb_units;loc++) { 
     locABCweight[loc]=1.0/nb_units;
   }
-  t0 = (*estimatingFnPtr)(locABCweight);  //need to reset any variable modified by estimatingFnPtr (slope() -> datamatrix::data used later by mantel test)
+  t0 = (*estimatingFnPtr)(locABCweight);  //need to reset any variable modified by estimatingFnPtr (slope() -> datamatrix::dataMat used later by mantel test)
   
   return 0;
 }
@@ -739,7 +739,7 @@ progress++;
   
   ///// bug corrected 2015/12/8 : added lines:
   std::fill(weights.begin(), weights.end(), 1.0/nb_units); 
-  t0 = (*estimatingFnPtr)(weights);  //need to reset any variabes modified by estimatingFnPtr (slope() -> datamatrix::data used later by mantel test)
+  t0 = (*estimatingFnPtr)(weights);  //need to reset any variabes modified by estimatingFnPtr (slope() -> datamatrix::dataMat used later by mantel test)
   
   // Return
   return 0;
