@@ -73,7 +73,15 @@ le nombre d'all[`e]les compt['e]s par parsefile;
 static bool debug=false;
 std::ostream cout_abyss(0); // so that the stream contents are ignored: http://stackoverflow.com/questions/7818371/printing-to-nowhere-with-ostream
 
-using namespace std;
+// using namespace std;
+using std::string;
+using std::cerr;
+using std::cin;
+using std::cout;
+using std::ios;
+using std::endl;
+using std::vector;
+
 static string EOLtype="";
 const string fichierIn="fichier.in";
 const string strEMPTY = "";
@@ -93,7 +101,7 @@ const string strEMPTY = "";
 
 #ifndef COMPATIBILITYRCPP
   #ifdef _WIN32
-    #include <windows.h>
+   #include <windows.h>
   #endif
 #endif
 
@@ -508,11 +516,11 @@ CLocusGP::CLocusGP(size_t identifiant, string locName) : CLocus(identifiant, loc
 
 CLocusGP::~CLocusGP() {
 //uses !=; not < for this iterator; also address the second element of the pair
-    for (map<int,CAllele *>::iterator p=alleles.begin();p!=alleles.end();p++) {
+    for (std::map<int,CAllele *>::iterator p=alleles.begin();p!=alleles.end();p++) {
       if (debug) RnoR_cerr<<"destr called for CAllele* allele[...] in CLocusGP::~CLocusGP()\n";
       delete (*p).second;
     }
-    for (map<int,CAllele *>::iterator p=galleles.begin();p!=galleles.end();p++) {
+    for (std::map<int,CAllele *>::iterator p=galleles.begin();p!=galleles.end();p++) {
       if (debug) RnoR_cerr<<"destr called for CAllele* gallele[...] in CLocusGP::~CLocusGP()\n";
       delete (*p).second;
     }
@@ -521,13 +529,13 @@ CLocusGP::~CLocusGP() {
 
 // teste l'existence d'un all[`e]le
 int CLocusGP::alleleExists(int num) {
-	map<int, CAllele *>::iterator p = alleles.find(num);
+	std::map<int, CAllele *>::iterator p = alleles.find(num);
 	return(p != alleles.end() ? -1 : 0);
 }
 
 // teste l'existence d'un all[`e]le
 int CLocusGP::galleleExists(int num) {
-	map<int, CAllele *>::iterator p = galleles.find(num);
+	std::map<int, CAllele *>::iterator p = galleles.find(num);
 	return(p != galleles.end() ? -1 : 0);
 }
 
@@ -752,7 +760,7 @@ CFichier_genepop::CFichier_genepop(string fn) {
 
 int CFichier_genepop::checkName() { // should not be called from constructor because (1) int return value; (2) if return -1 exit in migraine, not exit in genepop
     string fileNameOri;
-    fstream ORIfile(fileName.c_str(),ios::in|ios::out);
+    std::fstream ORIfile(fileName.c_str(),ios::in|ios::out);
     if ( ! ORIfile.is_open()) {
 	  fileNameOri=fileName;
 	  fileName+=".txt";
@@ -853,14 +861,14 @@ int CFichier_genepop::parseFile() {
 //    string tempname;
 //    char * tempnam;
 	string buf,typst;
-	stringstream stst(stringstream::in | stringstream::out);
+	std::stringstream stst(std::stringstream::in | std::stringstream::out);
 	size_t nbLoc=0;
 	int typ, g1=-1, g2=-1;
 	string::size_type pos; // position de la virgule
 	string::size_type lpos; // position des espaces entre genotypes
 	//string::size_type possp; // position d'un eventuel espace
 	string fileName2;
-	ifstream inFile(fileName.c_str(), ios::in);
+	std::ifstream inFile(fileName.c_str(), ios::in);
     if ( ! inFile.is_open()) {
         #ifdef COMPATIBILITYRCPP
             Rcpp::Rcerr<<"parseFile() cannot reopen "<<fileName.c_str()<<" although it could previously be opened."<<endl;
@@ -1118,16 +1126,16 @@ int CFichier_genepop::parseFile() {
 void translateToUnix(const char* filename);
 void translateToUnix(const char* filename) {
 #ifdef _WIN32
- fstream infile(filename, ios::in | ios::binary);
+ std::fstream infile(filename, ios::in | ios::binary);
 #else
- fstream infile(filename, ios::in);
+ std::fstream infile(filename, ios::in);
 #endif
    if (!infile) {
       noR_cout<< "Error: cannot find file: " << filename << endl;
       return;
    }
 
-   stringstream outstring;
+   std::stringstream outstring;
    char ch, lastch='\0';
    infile.get(ch);
    while (!infile.eof()) {
@@ -1148,15 +1156,15 @@ void translateToUnix(const char* filename) {
 
    infile.close();
 #ifdef _WIN32
-  fstream outfile(filename, ios::out | ios::binary);
+  std::fstream outfile(filename, ios::out | ios::binary);
 #else
-  fstream outfile(filename, ios::out);
+  std::fstream outfile(filename, ios::out);
 #endif
    if (!outfile.is_open()) {
 noR_cout<< "Error: cannot write to file: " << filename << endl;
       return;
    }
-   outstring << ends;
+   outstring << std::ends;
    outfile << outstring.str().c_str();
    outfile.close();
 }
@@ -1166,7 +1174,7 @@ int set_eof_check_EOLtype(string EOLFileName, bool set_eof){
   long pos,lngth;
 	char c='\0', buf;
     EOLtype="";
-    fstream ORIfile(EOLFileName.c_str(),ios::in|ios::out);
+    std::fstream ORIfile(EOLFileName.c_str(),ios::in|ios::out);
     if (!ORIfile.is_open()) {
         remove(fichierIn.c_str()); // otherwise, gets stuck if fichier.in contains an incorrect file name
         #ifdef COMPATIBILITYRCPP
@@ -1298,6 +1306,8 @@ CGenobilocus CFichier_genepop::read_bilocus(size_t pop,size_t loc1,size_t loc2)
 //    if (loc2<loc1) {cout<<"(!) From CGenobilocus CFichier_genepop::read_bilocus: loc2<loc1";getchar();}
 //cout<<"debut CFichier_genepop::read_bilocus"<<flush;getchar();
 	size_t nbLocMinusOne=loci.size()-1;
+	using std::stringstream;
+	using std::min;
 	stringstream stst(stringstream::in | stringstream::out);
     string buf,typst;
 	size_t popit=0; // numero de la derni[`e]re pops rencontr['e]e
@@ -1308,7 +1318,7 @@ CGenobilocus CFichier_genepop::read_bilocus(size_t pop,size_t loc1,size_t loc2)
 	size_t typ1=0,typ/*,bidonit*/,g1,g2;
 	CGenobilocus counts;
 	string fileName2;
-	ifstream inFile(fileName.c_str(), ios::in);
+	std::ifstream inFile(fileName.c_str(), ios::in);
     if ( ! inFile.is_open()) {
         #ifdef COMPATIBILITYRCPP
             // Rcpp::R
@@ -1496,7 +1506,7 @@ ssize_t typ/*,typ1*/;
 size_t ii,jj;
   	sortie.resize(mapmap.size());
   	ii=0;
-  	for (map<size_t,CGenotypes>::iterator iit=mapmap.begin();iit!=mapmap.end();iit++) {
+  	for (std::map<size_t,CGenotypes>::iterator iit=mapmap.begin();iit!=mapmap.end();iit++) {
         sortie[ii].resize(marginal.getNumber(),0);
         marginal.resetIterator();
         jj=0;
@@ -1567,7 +1577,7 @@ struct tm *currentTime;
 
 
 //ouverture du fichier de sortie FICHIER.IN
-ofstream fichier_out("fichier.in", ios::out);
+std::ofstream fichier_out("fichier.in", ios::out);
 
 //remplissage du fichier
 
@@ -1600,6 +1610,7 @@ vector<vector<double> >::iterator popu;
 //int pos;
 string buf,var;
 char bidon;
+using std::stringstream;
 stringstream stst(stringstream::in|stringstream::out);
      coord_pop.resize(pops.size());
 //cerr<<pops.size()<<endl;
@@ -1681,7 +1692,7 @@ double maxpot=0;
 
 vector<vector<double> >::iterator popi,popj;
   double pot,carre1,carre2;
-  ofstream stre;
+  std::ofstream stre;
   stre.open(file,ios::app);
   if(! stre.is_open()) {
     RnoR_cerr<<"computeCheckWriteDistMat cannot open file "<<file;
@@ -1694,7 +1705,7 @@ vector<vector<double> >::iterator popi,popj;
        carre2=pow((*popj)[1]-(*popi)[1],2);
        pot=sqrt(carre1+carre2);
        if (pot>maxpot) maxpot=pot;
-       stre<<fixed <<setprecision(15)<<pot<<" ";
+       stre<<std::fixed <<std::setprecision(15)<<pot<<" ";
       }
      stre<<endl;
    }
@@ -1716,7 +1727,7 @@ if (maxpot==0) return -1; else return 0;
 
 // renvoie vrai si le g['e]notype <genotype> existe
 bool CGenotypes::genotypeExists(size_t genotype) {
-	map<size_t, unsigned long int>::iterator p = genotypes.find(genotype);
+	std::map<size_t, unsigned long int>::iterator p = genotypes.find(genotype);
 	return(!(p == genotypes.end()));
 }
 
@@ -1831,7 +1842,7 @@ size_t CGenotypes::getNumber() {return genotypes.size();} //nb complete genotype
 void CGenotypes::printValues(CGenotypes *model, string *output, unsigned effectiveWidth, int foldLines) {
 	ssize_t genotype; // g['e]notype courant
 	size_t colCount; // comptage des colonnes en sortie
-	stringstream stst(stringstream::in|stringstream::out);
+	std::stringstream stst(std::stringstream::in|std::stringstream::out);
 
 	colCount = output->length();
 	model->resetIterator();
